ExtractLabels

Struct ExtractLabels 

pub struct ExtractLabels {
    pub name: String,
    pub common_labels: Labels,
    pub specific_labels: Vec<Labels>,
}
Common labels extracted from a very generic sequence of metric labels (key value pairs)

Fields

name: String

The metric name (from name label)

common_labels: Labels

Labels that are common to all metrics in the set

specific_labels: Vec<Labels>

Labels specific to each metric (excluding common labels)

Implementations

Source

impl ExtractLabels

pub fn new<'a, I, KV, K, V>(src: I, skip_labels: &[String]) -> Self
where I: Iterator<Item = &'a KV>, KV: Clone + Debug + 'a, K: Display + 'a, V: Display + 'a, &'a KV: IntoIterator<Item = (&'a K, &'a V)>,

Extract common and specific labels from an iterator of metric label sets.

Labels in skip_labels are excluded from both common and specific labels.