pub struct ExtractLabels {
pub name: String,
pub common_labels: Labels,
pub specific_labels: Vec<Labels>,
}Expand description
Common labels extracted from a very generic sequence of metric labels (key value pairs)
Fields
name: StringThe metric name (from name label)
common_labels: LabelsLabels that are common to all metrics in the set
specific_labels: Vec<Labels>Labels specific to each metric (excluding common labels)
Implementations